@@ -1,4 +1,5 @@
 from typing import (
+    Callable,
     List,
     Optional,
 )
@@ -17,40 +18,22 @@ from .utility import (
     toInt,
 )
 
-
-class SpiStub:
-    """Type definition for Spi class
-    """
-    def xfer2(self, data: List[int]) -> List[int]:
-        """spidev.xfer2:
-            1. Toggles Chip Select
-            2. transfers list of bytes
-            3. Toggles Chip Select (to latch data)
-
-        :data: List of bytes to write
-        :return: List of bytes from MISO pin
-        """
-        pass
-
-
 class SpinDevice:
     """Class providing access to a single SPIN device"""
 
     def __init__(
             self, position: int,
-            total_devices: int, spi: SpiStub,
-            chip_select_pin: Optional[int] = None):
+            total_devices: int,
+            spi_transfer: Callable[[List[int]], List[int]],
+        ):
         """
         :position: Position in chain, where 0 is the last device in chain
-        :chip_select_pin: Chip select pin,
-        if different from hardware SPI CS pin
         :total_devices: Total number of devices in chain
         :spi: SPI object used for serial communication
         """
         self._position: Final           = position
-        self._chip_select_pin: Final    = chip_select_pin
         self._total_devices: Final      = total_devices
-        self._spi: Final                = spi
+        self._spi_transfer: Final       = spi_transfer
 
         self._direction                 = Constant.DirForward
 
@@ -63,12 +46,10 @@ class SpinDevice:
         assert data >= 0
         assert data <= 0xFF
 
-        buffer = [0] * self._total_devices
+        buffer = [Command.Nop] * self._total_devices
         buffer[self._position] = data
 
-        # TODO: CS LOW
-        response = self._spi.xfer2(buffer)
-        # TODO: CS HIGH
+        response = self._spi_transfer(buffer)
 
         return response[self._position]
 
